# Copyright 1999-2014 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2
# $Header: $

EAPI=4
inherit flag-o-matic

DESCRIPTION="read and write grib2 files"
HOMEPAGE="http://www.cpc.ncep.noaa.gov/products/wesley/wgrib2/index.html"
SRC_URI="http://www.ftp.cpc.ncep.noaa.gov/wd51we/wgrib2/wgrib2.tgz.v${PV} -> wgrib2-${PV}.tgz"

LICENSE="public-domain"
SLOT="0"
KEYWORDS="~amd64 ~x86"
IUSE="mysql netcdf gctpc openmp +png +jpeg2k"

DEPEND="sci-libs/g2clib
		mysql? ( virtual/mysql )
		netcdf? ( sci-libs/netcdf[hdf5] )
		gctpc? ( sci-libs/gctpc )
		openmp? ( sys-devel/gcc[openmp] )
		png? ( media-libs/libpng )
		jpeg2k? ( media-libs/jasper )
		"
RDEPEND="${DEPEND}"

S=${WORKDIR}/grib2/wgrib2

src_prepare() {
	if ! use gctpc ; then
		epatch ${FILESDIR}/2.0.1/wgrib2-nogctpc.patch
		rm Gctpc.c gctpc_ll2xy.c new_grid_lambertc.c
	fi
	epatch ${FILESDIR}/2.0.1/wgrib2-config.patch
}

src_compile() {
	append-cppflags "-I.."
	append-ldflags "-lgrib2c -lm"
	if use gctpc ; then
		append-cppflags "-I/usr/include/gctp"
		append-ldflags "-lgctp"
	fi
	if use mysql ; then
		append-cflags "-DUSE_MYSQL"
		append-cppflags "-I/usr/include/mysql"
		append-ldflags "-lmysqlclient"
	fi
	if use netcdf ; then
		append-cflags "-DUSE_NETCDF4"
		append-ldflags `pkg-config --libs netcdf`
	fi
	if use openmp ; then
		append-cflags "-fopenmp"
	fi
	if use png ; then
		append-cflags "-DUSE_PNG"
		append-ldflags `pkg-config --libs libpng`
	fi
	if use jpeg2k ; then
		append-cflags "-DUSE_JASPER"
		append-cppflags "-I/usr/include/jasper"
		append-ldflags "-ljasper"
	fi
	emake
}

src_install() {
	dobin wgrib2
}
