# Copyright 1999-2014 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2
# $Header: $

EAPI=5

inherit eutils fortran-2

DESCRIPTION="Earth System Modeling Framework"
HOMEPAGE="http://www.earthsystemmodeling.org"
SRC_URI="http://downloads.sourceforge.net/project/esmf/ESMF_6_3_0r/ESMF_6_3_0rp1/esmf_6_3_0rp1_src.tar.gz -> ${P}.tar.gz"

LICENSE=""
SLOT="0"
KEYWORDS="~amd64"
IUSE="lapack netcdf xml openmp"

RDEPEND="
	lapack? ( 
			sci-libs/blas-reference
			sci-libs/lapack-reference
			)
	netcdf? ( sci-libs/netcdf )
	xml? 	( dev-libs/xerces-c )
	openmp? ( sys-devel/gcc[openmp] )
	"
DEPEND="${RDEPEND}
	sys-devel/make"

S="${WORKDIR}/esmf"

src_prepare() {
	epatch ${FILESDIR}/6.3.0_p1/warnings.patch
	epatch ${FILESDIR}/6.3.0_p1/remove_rpath.patch
}

src_compile() {
	export ESMF_DIR="`pwd`"

	if use lapack ; then
		export ESMF_LAPACK="netlib"
	else
		export ESMF_LAPACK="OFF"
	fi
	if use netcdf ; then
		export ESMF_NETCDF="split"
	fi
	if use xml ; then
		export ESMF_XERCES="standard"
		export ESMF_XERCES_INCLUDE="/usr/include/xercesc"
	fi

	if use openmp ; then
		export ESMF_OPENMP="ON"
	else 
		export ESMF_OPENMP="OFF"
	fi

# Linux systems build single-machine binaries as default
# no ESMF_COMM is set

	export ESMF_INSTALL_PREFIX="${D}/usr/"
	export ESMF_INSTALL_HEADERDIR="include/esmf"
	export ESMF_INSTALL_MODDIR="include"
	export ESMF_INSTALL_LIBDIR="lib"
	export ESMF_INSTALL_BINDIR="bin"
	export ESMF_INSTALL_DOCDIR="share/doc/ESMF/"

	make
}

src_test() {
	make all_tests
}

src_install() {
	export ESMFMKFILE=${S}/lib/libO/Linux.gfortran.64.mpiuni.default/esmf.mk
	make install
}

